/*
 *
 Project name:
       UNI Hall Click
 Copyright:
      (c) mikroElektronika, 2014.
 Revision History:
      20140820:
      - Initial release (RD);
 Description:
      UUNI HALL click is a simple solution for adding an unipolar Hall switch to
      your design. It carries the Melexis US5881 unipolar Hall-effect switch and
      a 74LVC1T45 single bit, dual supply translating transceiver. UNI HALL click
      communicates with the target board through the mikroBUS INT line. The
      board is designed to use either a 3.3V or 5V power supply (which also defines the
      logic level of the output signal).
      The unipolar Hall effect sensor on UNI HALL click is sensitive to north pole magnetic
      fieldswhen exposed to such a field, it outputs a LOW logic level. Othewise the
      output is a HIGH logic level. In its simplest application, UNI HALL click
      can be employed as part of a long lasting contactless proximity switch.
      However, magnets can be employed in various ways to infer the speed,
      position, or other properties of an object; there are countless ways to utilize
      UNI HALL click in your design.

 * Test configuration:
     MCU:             ATmega32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev. Board:      EasyAVR7
                      http://www.mikroe.com/easyavr/
     Oscillator:      Oscillator Frequency 8.0000 MHz, 8.0000 MHz Crystal
     ext. modules:    BI Hall Click
                      http://www.mikroe.com/click/bi-hall/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
                      
 NOTES:
      - Place UNI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW10-6 and SW10-8 switches for PORTB and PORTD LEDs.

*/

char cnt, old_cnt;

void interrupt_ISR () org IVT_ADDR_INT0 {            // Interrupt rutine
  SREG_I_bit = 0;                                    // Disable Interrupts
  cnt++;                                             // Increment variable cnt
  SREG_I_bit = 1;                                    // Enable Interrupts
}

void main() {
  DDRD = 0xFB;                                       // Set PD2 as input
  DDRB = 0xFF;                                       // Set PortB as output

  PortD = 0x00;
  PortB = 0x00;                                      // Starting value for PortB
  GICR = 0x40;                                       // Set the Interrupts
  ISC01_bit = 1;
  ISC00_bit = 1;
  cnt       = 0;
  old_cnt   = cnt;

  SREG_I_bit = 1;                                    // Enable Interrupts

   while(1) {
      if (old_cnt != cnt) {
         cnt = cnt-1;
         PORTB = cnt;
         old_cnt = cnt;
      }
   }
}